# Sprint 6 retrospective

## Sprint goal achievement

One the main high-impact goals in the previous meeting was the following: Implement intent-specific prompt modes. We have implemented the "contributors" feature that was one of the main requirements of the customer. Therefore, we achieved the sprint goal.

## Things that went well

1. Implementation of the new feature did not go difficult or wrong.
2. Current development process is easy and straightforward.
3. Customer is satisfied with the current progress.

## Problems

1. Problem with integration tests: initial tests are costly in terms of using tokens and each push to the main branch took some tokens from our account. Current solution: use QASTs that do not require tokens.

2. We did not focus enough on backlog and sprint tasks. Solution: focus on it first, instead of going straight to the development.

## What we will change

### High

1. Add a feature with time-bound summary

2. Show contributores in the summary

### Medium

1. Enhance observability and analytics

### Low

1. Add levels for logging

